@@ -521,6 +521,26 @@ class LocalPorvider(BaseProvider):
         """
         return FRP.repo_inside_holder(instruments,fields,**kws)
 
+    def repo_holder_data(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareinstHolderDerData'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_holder_data(instruments,fields,**kws)
+
+    def repo_manage_rewr(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareManagementHoldReward'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_manage_rewr(instruments,fields,**kws)
+
     def repo_issuedate_pre(self,instruments,fields = None,**kws):
         """
             table_name: 'AShareIssuingDatePredict'
