@@ -60,15 +60,14 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
         tidx = kws.get("tidx",self.tidx)
         defualt_si,defualt_ei = 0,1e7
         path = os.path.join(datapath,'merged.h5')
-        data = read_mergeh5(path,instruments,None,defualt_si,defualt_ei,tidx)
+        fields = kws.get("fields",None)
+        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,tidx)
         if data.empty:
             return data
         if ("start_date" in kws)&("end_date" in kws):
             start_date,end_date = kws.get("start_date"),kws.get("end_date")
             sd,ed = to_intdate(start_date),to_intdate(end_date)
             data = data.loc[(data[self.tidx]>=sd)&(data[self.tidx]<=ed)]
-        if kws.get("fields"):
-            data = data[kws.get("fields")]
         return data
 
     @print_func_time
